@@ -1,16 +1,17 @@
 """Functions for working with features in a raster dataset."""
 
 import json
+import time
+import warnings
 
 import numpy
+
 import rasterio
 from rasterio._features import _shapes, _sieve, _rasterize
+from rasterio.transform import IDENTITY, guard_transform
 
 
-DEFAULT_TRANSFORM = [0, 1, 0, 0, 0, 1]
-
-
-def shapes(image, mask=None, connectivity=4, transform=DEFAULT_TRANSFORM):
+def shapes(image, mask=None, connectivity=4, transform=IDENTITY):
     """Yields a (shape, image_value) pair for each feature in the image.
     
     The shapes are GeoJSON-like dicts and the image values are ints.
@@ -27,8 +28,13 @@ def shapes(image, mask=None, connectivity=4, transform=DEFAULT_TRANSFORM):
     if mask is not None and mask.dtype.type != rasterio.bool_:
         raise ValueError("Mask must be dtype rasterio.bool_")
 
+    if connectivity not in (4, 8):
+        raise ValueError("Connectivity Option must be 4 or 8")
+
+    transform = guard_transform(transform)
+
     with rasterio.drivers():
-        for s, v in _shapes(image, mask, connectivity, transform):
+        for s, v in _shapes(image, mask, connectivity, transform.to_gdal()):
             yield s, v
 
 
@@ -54,8 +60,9 @@ def sieve(image, size, connectivity=4, output=None):
 def rasterize(
         shapes, 
         out_shape=None, fill=0, output=None,
-        transform=DEFAULT_TRANSFORM,
-        all_touched=False):
+        transform=IDENTITY,
+        all_touched=False,
+        default_value=255):
     """Returns an image array with points, lines, or polygons burned in.
 
     A different value may be specified for each shape.  The shapes may
@@ -77,8 +84,12 @@ def rasterize(
 
     :param all_touched: if True, will rasterize all pixels touched, 
     otherwise will use GDAL default method.
+    :param default_value: value burned in for shapes if not provided as part of shapes.  Must be unsigned integer type (uint8).
     """
 
+    if not isinstance(default_value, int) or default_value > 255 or default_value < 0:
+        raise ValueError("default_value %s is not uint8/ubyte" % default_value)
+
     geoms = []
     for index, entry in enumerate(shapes):
         if isinstance(entry, (tuple, list)):
@@ -89,7 +100,7 @@ def rasterize(
                         index, value))
             geoms.append((geometry, value))
         else:
-            geoms.append((entry, 255))
+            geoms.append((entry, default_value))
     
     if out_shape is not None:
         out = numpy.empty(out_shape, dtype=rasterio.ubyte)
@@ -101,8 +112,10 @@ def rasterize(
     else:
         raise ValueError("An output image must be provided or specified")
     
+    transform = guard_transform(transform)
+
     with rasterio.drivers():
-        _rasterize(geoms, out, transform, all_touched)
+        _rasterize(geoms, out, transform.to_gdal(), all_touched)
     
     return out
 
